﻿///////////////////////////////////////////////////////////////////////////////
// file effects.js
// Copyright (c) 2012 Frédéric J. Rézeau. All rights reserved.
///////////////////////////////////////////////////////////////////////////////

(function (namespace, undefined) {
    "use strict";

    // Base Effect.
    namespace.Effect = function (x, y, radius) {
        if (!(this instanceof namespace.Effect)) {
            throw new Error("Constructor called as a function.");
        }

        this.x = x;                                     // Position x.
        this.y = y;                                     // Position y.
        this.radius = radius;                           // Bounding circle radius.
        this.vx = 0;                                    // Velocity x.
        this.vy = 0;                                    // Velocity y.
        this.friction = 1;                              // Friction.
        this.mass = 1;                                  // Mass.
        this.direction = namespace.DirectionEnum.None;  // Direction.
        this.rotationSpeed = 0;                         // Rotation speed.
        this.angle = 0;                                 // Current angle.
        this.gravity = 9.78;                            // Gravity factor.
        this.value = 0;                                 // Value of the effect.
        this.type = namespace.EffectTypeEnum.None;      // Effect type.
        this.activationCooldown = 0;                    // Determine when the effect becomes active.
        this.selfDestroyTime = -1;                      // Self destroy after this time (-1 for infinite time).
        this.startFadeTime = 1;                         // Start fade time.
        this.restoreBaseAngle = false;                  // Restore the base angle after rotation.
    };

    // Update the effect time-based properties.
    namespace.Effect.prototype.update = function (elapsed) {
        // Update the activation cooldown.
        if (this.activationCooldown > 0) {
            this.activationCooldown -= elapsed;
            if (this.activationCooldown < 0) {
                this.activationCooldown = 0;
            }
        }

        // Update the self destroy time.
        if (this.selfDestroyTime > 0) {
            this.selfDestroyTime -= elapsed;
            if (this.selfDestroyTime < 0) {
                this.selfDestroyTime = 0;
            }
        }

        // Apply friction on velocity X.
        if (this.vx > 0) {
            this.vx -= this.friction * elapsed;
            if (this.vx < 0) {
                this.vx = 0;
            }
        }
        else if (this.vx < 0) {
            this.vx += this.friction * elapsed;
            if (this.vx > 0) {
                this.vx = 0;
            }
        }

        // Apply friction on rotation speed.
        if (!this.restoreBaseAngle || (this.restoreBaseAngle && Math.abs(this.rotationSpeed) > 1)) {
            if (this.rotationSpeed > 0) {
                this.rotationSpeed -= this.friction * elapsed;
                if (this.rotationSpeed < 0) {
                    this.rotationSpeed = 0;
                }
            }
            else if (this.rotationSpeed < 0) {
                this.rotationSpeed += this.friction * elapsed;
                if (this.rotationSpeed > 0) {
                    this.rotationSpeed = 0;
                }
            }
        }
        else if (this.restoreBaseAngle) {
            this.rotationSpeed = 0;
        }

        // Restore the entity angle.
        if (this.restoreBaseAngle && this.rotationSpeed === 0 && this.angle !== 0) {
            var shortest = namespace.shortestArc(this.angle, 0);
            if (shortest > 0.1) {
                if (this.angle > 0) {
                    this.angle += (Math.PI * 2) * elapsed;
                }
                else {
                    this.angle -= (Math.PI * 2) * elapsed;
                }
            }
            else {
                this.angle = 0;
            }
        }

        // Apply rotation to angle.
        this.angle = this.rotationSpeed ? (this.angle + this.rotationSpeed * (Math.PI * 2) * elapsed) % (Math.PI * 2) : this.angle;

        // Apply gravity.
        this.vy += this.gravity * elapsed;

        // Apply velocity.
        this.y += this.vy * elapsed;
        this.x += this.vx * elapsed;
    };

    // Impact Effect.
    namespace.ImpactEffect = function (x, y, radius) {
        if (!(this instanceof namespace.ImpactEffect)) {
            throw new Error("Constructor called as a function.");
        }

        namespace.Effect.call(this, x, y, radius);

        this.gravity = 0;
        this.friction = 2;
        this.mass = 0.5;
        this.selfDestroyTime = 0.3;
        this.startFadeTime = 0.2;
        this.type = namespace.EffectTypeEnum.Impact;
        this.value = 0;
        this.angle = Math.random() * 2;
        this.rotationSpeed = 0.2 * Math.PI;
        this.vx = (Math.random() > 0.5) ? 0.3 : -0.3;
        this.vy = -(0.5 + Math.random());
    };

    // Setup the ImpactEffect prototype chain.
    namespace.ImpactEffect.prototype = Object.create(namespace.Effect.prototype);

    // Blood Splatter Effect.
    namespace.BloodSplatterEffect = function (x, y, radius) {
        if (!(this instanceof namespace.BloodSplatterEffect)) {
            throw new Error("Constructor called as a function.");
        }

        namespace.Effect.call(this, x, y, radius);

        this.gravity = 0;
        this.friction = 2;
        this.mass = 0.5;
        this.selfDestroyTime = 0.3;
        this.startFadeTime = 0.1;
        this.type = namespace.EffectTypeEnum.BloodSplatter;
        this.value = 0;
        this.angle = Math.random() * 2;
        this.rotationSpeed = 0.2 * Math.PI;
        this.vx = (Math.random() > 0.5) ? 0.3 : -0.3;
        this.vy = -(0.5 + Math.random());
    };

    // Setup the BloodSplatterEffect prototype chain.
    namespace.BloodSplatterEffect.prototype = Object.create(namespace.Effect.prototype);

    // Small Smoke Effect.
    namespace.SmallSmokeEffect = function (x, y, radius) {
        if (!(this instanceof namespace.SmallSmokeEffect)) {
            throw new Error("Constructor called as a function.");
        }

        namespace.Effect.call(this, x, y, radius);

        this.gravity = 0;
        this.friction = 2;
        this.mass = 0.5;
        this.selfDestroyTime = 0.3;
        this.startFadeTime = 0.4;
        this.type = namespace.EffectTypeEnum.SmallSmoke;
        this.value = 0;
        this.angle = Math.random() * 2;
        this.rotationSpeed = 0.2 * Math.PI;
        this.vx = (Math.random() > 0.5) ? 0.3 : -0.3;
        this.vy = -(0.5 + Math.random());
    };

    // Setup the SmallSmokeEffect prototype chain.
    namespace.SmallSmokeEffect.prototype = Object.create(namespace.Effect.prototype);

    // Big Smoke Effect.
    namespace.BigSmokeEffect = function (x, y, radius) {
        if (!(this instanceof namespace.BigSmokeEffect)) {
            throw new Error("Constructor called as a function.");
        }

        namespace.Effect.call(this, x, y, radius);

        this.gravity = 0;
        this.friction = 0;
        this.mass = 0.5;
        this.selfDestroyTime = 0.9;
        this.type = namespace.EffectTypeEnum.BigSmoke;
        this.value = 0;
        this.angle = x + 1;
        this.rotationSpeed = 0.3 * Math.PI;
        this.vy = -(0.1 + Math.random() * 0.5);
        this.startFadeTime = 0.9;
    };

    // Setup the BigSmokeEffect prototype chain.
    namespace.BigSmokeEffect.prototype = Object.create(namespace.Effect.prototype);

    // Explosion Effect.
    namespace.ExplosionEffect = function (x, y, radius) {
        if (!(this instanceof namespace.ExplosionEffect)) {
            throw new Error("Constructor called as a function.");
        }

        namespace.Effect.call(this, x, y, radius);

        this.gravity = 0;
        this.friction = 0;
        this.mass = 0.5;
        this.selfDestroyTime = 0.7;
        this.type = namespace.EffectTypeEnum.Explosion;
        this.value = 0;
        this.angle = x + 1;
        this.rotationSpeed = 0.1 * Math.PI;
        this.vy = -(0.1 + Math.random() * 0.5);
        this.startFadeTime = 0.4;
    };

    // Setup the ExplosionEffect prototype chain.
    namespace.ExplosionEffect.prototype = Object.create(namespace.Effect.prototype);

    // Projectile Effect.
    namespace.ProjectileEffect = function (x, y, radius, angle, vx, vy, type, value) {
        if (!(this instanceof namespace.ProjectileEffect)) {
            throw new Error("Constructor called as a function.");
        }

        namespace.Effect.call(this, x, y, radius);

        this.angle = angle;
        this.vx = vx;
        this.vy = vy;
        this.type = type;
        this.value = value;
        this.gravity = 0;
        this.friction = 0;
        this.selfDestroyTime = 3;
        this.count = 0;
    };

    // Setup the ProjectileEffect prototype chain.
    namespace.ProjectileEffect.prototype = Object.create(namespace.Effect.prototype);

    // Gun Fire Effect.
    namespace.CartridgeCaseEffect = function (x, y, radius, direction) {
        if (!(this instanceof namespace.CartridgeCaseEffect)) {
            throw new Error("Constructor called as a function.");
        }

        namespace.Effect.call(this, x, y, radius);

        var speed = 2 + Math.random();
        this.friction = 1;
        this.mass = 0.7;
        this.selfDestroyTime = 2;
        this.type = namespace.EffectTypeEnum.CartridgeCase;
        this.value = 0;
        this.angle = Math.random();
        this.rotationSpeed = (0.6 + Math.random() * 0.15) * Math.PI;
        this.vx = (direction === namespace.DirectionEnum.Left) ? -speed : speed;
        this.vy = -speed;
        this.direction = direction;
    };

    // Setup the CartridgeCaseEffect prototype chain.
    namespace.CartridgeCaseEffect.prototype = Object.create(namespace.Effect.prototype);

})(window.ZCJGame = window.ZCJGame || {});
