﻿///////////////////////////////////////////////////////////////////////////////
// file utils.js
// Copyright (c) 2012 Frédéric J. Rézeau. All rights reserved.
///////////////////////////////////////////////////////////////////////////////

(function (namespace, undefined) {
    "use strict";

    var prevTime = new Date(), frames = 0, fps = 0;

    // Get the current fps.
    namespace.getFPS = function () {
        var getFrames = function () {
            ++frames;
            var nowTime = new Date();
            if (nowTime.getTime() - prevTime.getTime() > 1000) {
                fps = frames;
                frames = 0;
                prevTime = nowTime;
            }
            return fps;
        };
        return getFrames();
    };

    // Clamp the value to (min, max) range.
    namespace.clamp = function (value, min, max) {
        return Math.max(min, Math.min(max, value));
    };

    // Determine whether the circle (x, y, radius) intersects with rectangle (left, top, right, bottom).
    namespace.circleRectIntersect = function (x, y, radius, left, top, right, bottom) {
        var dx = x - namespace.clamp(x, left, right);
        var dy = y - namespace.clamp(y, top, bottom);
        return (dx * dx + dy * dy) < (radius * radius);
    };

    // Calculate the distance between the two points (x1, y1) and (x2, y2).
    namespace.distance = function (x1, y1, x2, y2) {
        var xd = x2 - x1;
        var yd = y2 - y1;
        return Math.sqrt(xd * xd + yd * yd);
    };

    // Add vector (x2, y2) to (x1, y1).
    namespace.vectorAdd = function (x1, y1, x2, y2) {
        return { "x": x1 + x2, "y": y1 + y2 };
    };

    // Substract vector (x2, y2) from (x1, y1).
    namespace.vectorSubstract = function (x1, y1, x2, y2) {
        return { "x": x1 - x2, "y": y1 - y2 };
    };

    // Multiply (x, y) by factor f.
    namespace.vectorMultiply = function (x, y, f) {
        return { "x": x * f, "y": y * f };
    };

    // Divide (x, y) by denominator f.
    namespace.vectorDivide = function (x, y, f) {
        if (f === 0) {
            return { "x": x, "y": y };
        }
        return { "x": x / f, "y": y / f };
    };

    // Calculate the dot product with vectors (x1, y1) and (x2, y2).
    namespace.vectorDotProduct = function (x1, y1, x2, y2) {
        return (x1 * x2 + y1 * y2);
    };

    // Calculate the magnitude of vector (x, y).
    namespace.vectorLength = function (x, y) {
        return Math.sqrt((x * x) + (y * y));
    };

    // Calculate the normalized vector (x, y).
    namespace.vectorNormalize = function (x, y) {
        var l = namespace.vectorLength(x, y);
        if (l === 0) {
            return { "x": x, "y": y };
        }
        return { "x": x / l, "y": y / l };
    };

    // Rotate the vector (x, y) by angle (in radians).
    namespace.vectorRotate = function (x, y, angle) {
        var ca = Math.cos(angle);
        var sa = Math.sin(angle);
        var x1 = ca * x - sa * y;
        var y1 = sa * x + ca * y;
        return { "x": x1, "y": y1 };
    };

    // Calculate the angle between the two vectors (x1, y1) and (x2, y2).
    namespace.vectorAngle = function (x1, y1, x2, y2) {
        return Math.atan2(y2 - y1, x2 - x1);
    };

    // Calculate the vector for a given angle.
    namespace.vectorFromAngle = function (angle) {
        return { "x": Math.cos(angle), "y": Math.sin(angle) };
    };

    // Convert the angle from radians to degrees.
    namespace.toDegrees = function (angle) {
        return angle * (180 / Math.PI);
    };

    // Convert the angle from degrees to radians.
    namespace.toRadians = function (angle) {
        return angle * (Math.PI / 180);
    };

    // Determine the shortest rotation angle between a and b (in radians).
    namespace.shortestArc = function (a, b) {
        var distance = Math.abs(a - b);
        if (distance > Math.PI) {
            distance = Math.PI * 2 - distance;
        }
        return distance;
    };

    // Check whether 2 axis-aligned rectangles intersect.
    namespace.rectIntersect = function (l1, t1, r1, b1, l2, t2, r2, b2) {
        return !(b1 < t2 || t1 > b2 || r1 < l2 || l1 > r2);
    };

    // Check whether the point (x, y) is within the rect (l, t, r, b).
    namespace.pointInRect = function (x, y, l, t, r, b) {
        return (x > l && x < r && y > t && y < b);
    };

    // Preload images with completion callback.
    namespace.loadImages = function (sources, callback) {
        var i, len, images = {}, loadedImages = 0, source;
        var onLoad = function () {
            if (++loadedImages === len && callback) {
                callback(images);
            }
        };
        for (i = 0, len = sources.length; i < len; i += 1) {
            source = sources[i];
            images[source.id] = new Image();
            images[source.id].onload = onLoad;
            images[source.id].src = source.src;
        }
    };
    // Preload resources with completion callback.
    namespace.loadResources = function (sources, callback, stepCallback) {
        var i, len, resources = {}, loadedResources = 0, source;
        var onLoad = function () {
            if (++loadedResources === len && callback) {
                callback(resources);
            }

            if (stepCallback) {
                stepCallback(loadedResources, len);
            }
        };
        for (i = 0, len = sources.length; i < len; i += 1) {
            source = sources[i];
            if (source.type === "img") {
                resources[source.id] = new Image();
                resources[source.id].onload = onLoad;
                resources[source.id].src = source.src;
            }
            else if (source.type === "snd") {
                resources[source.id] = new Audio();
                resources[source.id].preload = "auto";
                resources[source.id].onloadeddata = onLoad;
                resources[source.id].src = source.src;
            }
        }
    };

})(window.ZCJGame = window.ZCJGame || {});

/*
// Helper function to center the canvas on screen.
$.fn.center = function () {
    "use strict";

    this.css("position", "absolute");
    this.css("top", Math.max(0, (($(window).height() - $(this).outerHeight()) / 2) + $(window).scrollTop()) + "px");
    this.css("left", Math.max(0, (($(window).width() - $(this).outerWidth()) / 2) + $(window).scrollLeft()) + "px");
    return this;
};*/
